tonalanalysistools.ChordInversion
=================================

.. abjad-lineage:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion

.. autoclass:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.extent_to_figured_bass_string
      ~abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.name
      ~abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.number
      ~abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.title
      ~abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.__eq__
      ~abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.__format__
      ~abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.__ne__
      ~abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.name
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.number
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.title
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.extent_to_figured_bass_string
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.__format__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordInversion.ChordInversion.__repr__
   :noindex:
